@@ -1,8 +1,12 @@
 package Net::RackSpace::CloudServers::Flavor;
-our $VERSION = '0.09_40';
+
+BEGIN {
+    $Net::RackSpace::CloudServers::Flavor::VERSION = '0.12_01';
+}
 use warnings;
 use strict;
 use Any::Moose;
+use Carp;
 
 has 'cloudservers' => ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
 has 'id'           => ( is => 'ro', isa => 'Int',                          required => 1 );
@@ -19,7 +23,7 @@ Net::RackSpace::CloudServers::Flavor - a RackSpace CloudServers Flavor
 
 =head1 VERSION
 
-version 0.09_40
+version 0.12_01
 
 =head1 SYNOPSIS
 
